/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package benchmark.ring;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.message.Chunk;
import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.util.Util;

/**
 * {@link PayLoadChunk }implementation.
 */
public class PayLoadChunkImpl extends AbstractChunk
    implements
      PayLoadChunk,
      Externalizable
{

  private byte[] payLoad = null;

  /**
   * @see PayLoadChunk#setPayLoadSize(int)
   */
  public void setPayLoadSize(int nbByte)
  {
    payLoad = new byte[nbByte];
  }

  /**
   * @see PayLoadChunk#getPayLoadSize()
   */
  public int getPayLoadSize()
  {
    if (payLoad == null)
    {
      return 0;
    }
    return payLoad.length;
  }

  /**
   * @see Chunk#getType()
   */
  public ChunkType getType()
  {
    return TYPE;
  }

  /**
   * @see Chunk#transfertState(Chunk)
   */
  public void transfertState(Chunk newInstance)
  {
    ((PayLoadChunk) newInstance).setPayLoadSize(getPayLoadSize());
  }

  /**
   * @see Chunk#recycle()
   */
  public void recycle()
  {
    payLoad = null;
  }

  /**
   * @see java.io.Externalizable#readExternal(java.io.ObjectInput)
   */
  public void readExternal(ObjectInput in) throws IOException,
      ClassNotFoundException
  {
    payLoad = Util.readExternalByteArray(in);
  }

  /**
   * @see java.io.Externalizable#writeExternal(java.io.ObjectOutput)
   */
  public void writeExternal(ObjectOutput out) throws IOException
  {
    Util.writeExternalByteArray(out, payLoad);
  }

}