/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package benchmark.ring;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.net.InetAddress;

import org.objectweb.dream.channel.IPChannelDestinationChunk;
import org.objectweb.dream.message.AbstractNonExtensibleMessage;
import org.objectweb.dream.message.Message;
import org.objectweb.dream.util.Util;

/**
 * Non extensible message implementation of a message containning a PayLoadChunk
 */
public class PayLoadMessage extends AbstractNonExtensibleMessage
    implements
      PayLoadChunk,
      IPChannelDestinationChunk,
      Externalizable
{

  private byte[]                payLoad = null;
  private transient InetAddress destinationAddr;
  private transient int         destinationPort;

  /**
   * @see PayLoadChunk#setPayLoadSize(int)
   */
  public void setPayLoadSize(int nbByte)
  {
    payLoad = new byte[nbByte];
  }

  /**
   * @see PayLoadChunk#getPayLoadSize()
   */
  public int getPayLoadSize()
  {
    if (payLoad == null)
    {
      return 0;
    }
    return payLoad.length;
  }

  /**
   * @see IPChannelDestinationChunk#getChannelDestinationAddr()
   */
  public InetAddress getChannelDestinationAddr()
  {
    return destinationAddr;
  }

  /**
   * @see IPChannelDestinationChunk#getChannelDestinationPort()
   */
  public int getChannelDestinationPort()
  {
    return destinationPort;
  }

  /**
   * @see IPChannelDestinationChunk#setChannelDestinationAddr(InetAddress)
   */
  public void setChannelDestinationAddr(InetAddress addr)
  {
    destinationAddr = addr;
  }

  /**
   * @see IPChannelDestinationChunk#setChannelDestinationPort(int)
   */
  public void setChannelDestinationPort(int port)
  {
    this.destinationPort = port;
  }

  /**
   * @see Message#transfertChunkStates(Message)
   */
  public void transfertChunkStates(Message newInstance)
  {
    PayLoadChunk chunk = (PayLoadChunk) newInstance
        .getChunk(PayLoadChunk.DEFAULT_NAME);
    chunk.setPayLoadSize(getPayLoadSize());
  }

  /**
   * @see Message#recycle()
   */
  public void recycle()
  {
    payLoad = null;
  }

  /**
   * @see Externalizable#readExternal(ObjectInput)
   */
  public void readExternal(ObjectInput in) throws IOException,
      ClassNotFoundException
  {
    payLoad = Util.readExternalByteArray(in);
  }

  /**
   * @see Externalizable#writeExternal(ObjectOutput)
   */
  public void writeExternal(ObjectOutput out) throws IOException
  {
    Util.writeExternalByteArray(out, payLoad);
  }
}