/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package utobcast.basic;

import java.net.InetAddress;
import java.util.HashMap;
import java.util.Map;

import org.objectweb.dream.adl.FactoryFactory;
import org.objectweb.dream.protocol.utobcast.ProcessMembership;
import org.objectweb.dream.util.Util;
import org.objectweb.fractal.adl.Factory;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.control.ContentController;
import org.objectweb.fractal.rmi.registry.Registry;
import org.objectweb.fractal.util.Fractal;

import utobcast.TCPProcess;

/**
 * A class that defines a main method to launch the example.
 */
public class Main
{

  /**
   * Starts the example.
   * 
   * @param args command line arguments
   * @throws Exception if an error occurs.
   */
  public static void main(String[] args) throws Exception
  {
    Factory f = FactoryFactory.getFactory();
    Map ctx = new HashMap();

    // Create the composite
    ctx.put("naming-service", Registry.getRegistry("localhost"));
    Component composite = (Component) f.newComponent(
        "utobcast.basic.UTOBcastExample(33333)", ctx);

    // Retrieve the nodes
    ContentController contentController = Fractal
        .getContentController(composite);

    //Create processes
    Component[] nodes = contentController.getFcSubComponents();
    TCPProcess[] tcpProcesses = new TCPProcess[nodes.length];
    for (int i = 0; i < nodes.length; i++)
    {
      tcpProcesses[i] = new TCPProcess((short) i, InetAddress.getLocalHost(),
          30000 + i);
    }

    // Configure each node
    for (int i = 0; i < nodes.length; i++)
    {
      // Start the UTOBcastProtocol component
      ContentController cc = Fractal.getContentController(nodes[i]);
      Component utoBcastProtocol = Util.getComponentByName(cc,
          "UTOBcastProtocol");
      Fractal.getLifeCycleController(utoBcastProtocol).startFc();
      // Configure membership
      ProcessMembership processMembershipItf = (ProcessMembership) Util
          .getComponentByName(cc, "UTOBcastProtocol/ProcessMembership")
          .getFcInterface(ProcessMembership.ITF_NAME);
      processMembershipItf.setLeader(tcpProcesses[0]);
      processMembershipItf.setBackup(tcpProcesses[1]);
      processMembershipItf.setMyself(tcpProcesses[i]);
    }

    // Retrieve the process membership component of the leader
    ProcessMembership leaderProcessMembershipItf = (ProcessMembership) Util
        .getComponentByName(contentController,
            "0/UTOBcastProtocol/ProcessMembership").getFcInterface(
            ProcessMembership.ITF_NAME);

    // Retrieve the process membership component of the backup
    ProcessMembership backupMembershipItf = (ProcessMembership) Util
        .getComponentByName(contentController,
            "1/UTOBcastProtocol/ProcessMembership").getFcInterface(
            ProcessMembership.ITF_NAME);

    for (int i = 0; i < tcpProcesses.length; i++)
    {
      leaderProcessMembershipItf.addProcess(tcpProcesses[i]);
      backupMembershipItf.addProcess(tcpProcesses[i]);
    }

    // Start the test (note that some components have already been started)
    Fractal.getLifeCycleController(composite).startFc();

  }
}