/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.channel;

import java.net.UnknownHostException;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * Attribute controller interface for AddIPChannel components.
 */
public interface AddIPChannelAttributeController extends AttributeController
{

  /**
   * Returns the name of added chunks.
   * 
   * @return the name of added chunks.
   */
  String getChunkName();

  /**
   * Sets the name of the added chunk.
   * 
   * @param chunkName the name of added chunks .
   */
  void setChunkName(String chunkName);

  /**
   * Returns the inet addresse put in chunks.
   * 
   * @return a string representation of the inet addresse put in chunks.
   */
  String getInetAddress();

  /**
   * Sets the inet addresse put in chunks.
   * 
   * @param inetAddress a String representing the inet addresse put in chunks.
   * @throws UnknownHostException if the given inet address can't be resolved
   * @see java.net.InetAddress#getByName(java.lang.String)
   */
  void setInetAddress(String inetAddress) throws UnknownHostException;

  /**
   * Returns the port number put in chunks.
   * 
   * @return the port number put in chunks.
   */
  int getPort();

  /**
   * Sets the port number put in chunks.
   * 
   * @param port the port number put in chunks.
   */
  void setPort(int port);
}