/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.channel;

import java.net.InetAddress;

import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.message.ChunkTypeImpl;

/**
 * Chunk interface used to identify the IP channel that send the message.
 */
public interface IPChannelSourceChunk
{
  /** The default name of chunks of this type. */
  String    DEFAULT_NAME = "IPChannelSource";

  /** The Chunk type of chunks that implements this interface. */
  ChunkType TYPE         = new ChunkTypeImpl(IPChannelSourceChunk.class,
                             IPChannelSourceChunkImpl.class);

  /**
   * Returns the inet address of the ChannelOut.
   * 
   * @return the inet address of the ChannelOut.
   */
  InetAddress getChannelSourceAddr();

  /**
   * Sets the inet address of the ChannelOut.
   * 
   * @param addr the inet address.
   */
  void setChannelSourceAddr(InetAddress addr);

  /**
   * Returns the listening port of the ChannelOut.
   * 
   * @return the listening port of the ChannelOut.
   */
  int getChannelSourcePort();

  /**
   * Sets the listening port of the ChannelOut.
   * 
   * @param port the listening port.
   */
  void setChannelSourcePort(int port);
}