/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.channel;

import java.net.UnknownHostException;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * Attribute controller for socket managers that only manage one opened socket.
 */
public interface SocketManagerIPStaticAttributeController
    extends
      AttributeController
{
  /**
   * Returns the destination hostname. Each message will be send to this
   * hostname.
   * 
   * @return the <code>destinationHostname</code> attribute value.
   */
  String getDestinationHostname();

  /**
   * Sets the <code>destinationHostname</code> attribute value.
   * 
   * @param hostname the new <code>destinationHostname</code> attribute value.
   * @throws UnknownHostException if the given hostname can't be resolved.
   * @see #getDestinationHostname()
   */
  void setDestinationHostname(String hostname) throws UnknownHostException;

  /**
   * Returns the destination port.
   * 
   * @return the <code>destinationPort</code> attribute value.
   */
  int getDestinationPort();

  /**
   * Sets the <code>destinationPort</code> attribute value.
   * 
   * @param port the new <code>destinationPort</code> attribute value.
   */
  void setDestinationPort(int port);
}