/**
 * Dream
 * Copyright (C) 2003 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: vivien.quema@inrialpes.fr
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.protocol;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.io.Serializable;

/**
 * Implementation of the {@link Process}interface. This class can be overriden
 * to produce customized processes for particular protocols.
 */
public class ProcessImpl implements Cloneable,
 //      Externalizable,
    Serializable, Process, Comparable
{

  // TODO change for transient
  /**
   * Identifier of the process.
   */
  protected short id;

  /**
   * Allocates a new ProcessImpl object.
   * 
   * @param id the identifier of the process
   */
  public ProcessImpl(short id)
  {
    this.id = id;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Process interface
  // ---------------------------------------------------------------------------

  /**
   * Returns the identifier of the process.
   * 
   * @return the identifier of the process.
   */
  public final short getId()
  {
    return id;
  }

  /**
   * @see org.objectweb.dream.protocol.Process#setId(short)
   */
  public void setId(short id)
  {
    this.id = id;
  }

  /**
   * @see java.lang.Object#clone()
   */
  public Object clone() throws CloneNotSupportedException
  {
    return super.clone();
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Externalizable interface
  // ---------------------------------------------------------------------------

  /**
   * @see java.io.Externalizable#writeExternal(java.io.ObjectOutput)
   */
  public void writeExternal(ObjectOutput out) throws IOException
  {
    out.writeShort(id);
  }

  /**
   * @see java.io.Externalizable#readExternal(java.io.ObjectInput)
   */
  public void readExternal(ObjectInput in) throws IOException,
      ClassNotFoundException
  {
    id = in.readShort();
  }

  // ---------------------------------------------------------------------------
  // Overriden methods
  // ---------------------------------------------------------------------------

  /**
   * @see java.lang.Object#equals(java.lang.Object)
   */
  public boolean equals(Object arg0)
  {
    if (arg0 instanceof Process)
    {
      boolean res = ((ProcessImpl) arg0).id == id;
      return res;
    }
    else
    {
      return false;
    }
  }

  /**
   * @see java.lang.Object#hashCode()
   */
  public int hashCode()
  {
    return id;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Comparable interface
  // ---------------------------------------------------------------------------

  /**
   * @see java.lang.Comparable#compareTo(java.lang.Object)
   */
  public int compareTo(Object o)
  {
    return (((Process) o).getId() - getId());
  }

}