/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package org.objectweb.dream.pushwithreturn;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.message.ExtensibleMessage;
import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.manager.MessageManager;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * This generator generates <code>KeyInteger</code> objects with an increasing
 * integer. It adds a <code>KeyChunk</code> chunk to the message.
 */
public class KeyGeneratorIntegerImpl extends AbstractComponent
    implements
      KeyGenerator
{
  /** The "All" Integer key. */
  public static final KeyInteger ALL_INTEGER_KEY = new KeyInteger(0, true);

  /** The integer contained in the last generated key. */
  int                            lastInSequence  = 0;

  /** The client interface used to access the message manager. */
  MessageManager                 messageManagerItf;

  // ---------------------------------------------------------------------------
  // Implementation of the KeyGenerator interface.
  // ---------------------------------------------------------------------------
  /**
   * @see org.objectweb.dream.pushwithreturn.KeyGenerator#generateKey(org.objectweb.dream.message.Message)
   */
  public Key generateKey(Message message) throws Exception
  {
    KeyChunk keyChunk = (KeyChunk) message.getChunk(KeyChunk.DEFAULT_NAME);
    if (keyChunk != null)
    {
      return keyChunk.getKey();
    }
    if (message instanceof ExtensibleMessage)
    {
      KeyInteger key = new KeyInteger(++lastInSequence, false);
      keyChunk = (KeyChunk) messageManagerItf.createChunk(KeyChunk.TYPE);
      keyChunk.setKey(key);
      ((ExtensibleMessage) message).addChunk(KeyChunk.DEFAULT_NAME,
          KeyChunk.TYPE, keyChunk);
      return key;
    }
    else
    {
      throw new Exception("Unable to add KeyChunk to message " + message);
    }
  }

  // ---------------------------------------------------------------------------
  // Implementation of the BindingController interface.
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(java.lang.String,
   *      java.lang.Object)
   */
  public void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(MessageManager.ITF_NAME))
    {
      messageManagerItf = (MessageManager) serverItf;
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{MessageManager.ITF_NAME};
  }

}